==> GEOsubmission_1.0.0.zip: GEOsubmission/doc/GEOsubmission.R <==
###################################################
### chunk number 1: loadGEOsubmission
###################################################
library(GEOsubmission)


###################################################
### chunk number 2: sampleSerieslabels
###################################################
sampleID<-c('1','2')
seriesName<-'neuronalCultures'


###################################################
### chunk number 3: exampleWcel eval=FALSE
###################################################
## microarray2soft(sampleID,'sampleInfo.txt',seriesName,'seriesInfo.txt',
## softname='mydata.soft')
## 


###################################################
### chunk number 4: dataDirectory
###################################################
dataDirectory<-system.file('extdata',package='GEOsubmission')


###################################################
### chunk number 5: showInfoFiles eval=FALSE
###################################################
## read.delim(file.path(dataDirectory,'sampleInfo.txt'))
## read.delim(file.path(dataDirectory,'seriesInfo.txt'))


###################################################
### chunk number 6: softFilename
###################################################
soft_example_fullpath<-tempfile(pattern='soft_example')
soft_example_name<-basename(soft_example_fullpath)
soft_example_dir<-dirname(soft_example_fullpath)


###################################################
### chunk number 7: exampleWexpressionmatrix
###################################################
microarray2soft(sampleID,'sampleInfo.txt',seriesName,'seriesInfo.txt',
datadir=dataDirectory,writedir=soft_example_dir,
softname=soft_example_name,expressionmatrix='expressionNormalized.txt')



###################################################
### chunk number 8: softContent
###################################################
readLines(soft_example_fullpath)


###################################################
### chunk number 9: deleteSoft
###################################################
## Clean-up
unlink(soft_example_fullpath)


###################################################
### chunk number 10: showExpressionmatrix eval=FALSE
###################################################
## read.delim(file.path(dataDirectory,'expressionNormalized.txt'))


###################################################
### chunk number 11: exampleWstdOutput eval=FALSE
###################################################
## microarray2soft(c('1','2'),'sampleInfo.txt',seriesName,'seriesInfo.txt',
## datadir=dataDirectory,softname='',expressionmatrix='expressionNormalized.txt',
## verbose=FALSE)
## 


###################################################
### chunk number 12: sessionInfo
###################################################
sessionInfo()

==> GEOsubmission_1.2.0.zip: GEOsubmission/doc/GEOsubmission.R <==
###################################################
### chunk number 1: loadGEOsubmission
###################################################
#line 38 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmperpKJq/R.INSTALL2d80412e/GEOsubmission/inst/doc/GEOsubmission.Rnw"
library(GEOsubmission)


###################################################
### chunk number 2: sampleSerieslabels
###################################################
#line 42 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmperpKJq/R.INSTALL2d80412e/GEOsubmission/inst/doc/GEOsubmission.Rnw"
sampleID<-c('1','2')
seriesName<-'neuronalCultures'


###################################################
### chunk number 3: exampleWcel eval=FALSE
###################################################
## #line 47 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmperpKJq/R.INSTALL2d80412e/GEOsubmission/inst/doc/GEOsubmission.Rnw"
## microarray2soft(sampleID,'sampleInfo.txt',seriesName,'seriesInfo.txt',
## softname='mydata.soft')
## 


###################################################
### chunk number 4: dataDirectory
###################################################
#line 57 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmperpKJq/R.INSTALL2d80412e/GEOsubmission/inst/doc/GEOsubmission.Rnw"
dataDirectory<-system.file('extdata',package='GEOsubmission')


###################################################
### chunk number 5: showInfoFiles eval=FALSE
###################################################
## #line 60 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmperpKJq/R.INSTALL2d80412e/GEOsubmission/inst/doc/GEOsubmission.Rnw"
## read.delim(file.path(dataDirectory,'sampleInfo.txt'))
## read.delim(file.path(dataDirectory,'seriesInfo.txt'))


###################################################
### chunk number 6: softFilename
###################################################
#line 67 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmperpKJq/R.INSTALL2d80412e/GEOsubmission/inst/doc/GEOsubmission.Rnw"
soft_example_fullpath<-tempfile(pattern='soft_example')
soft_example_name<-basename(soft_example_fullpath)
soft_example_dir<-dirname(soft_example_fullpath)


###################################################
### chunk number 7: exampleWexpressionmatrix
###################################################
#line 74 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmperpKJq/R.INSTALL2d80412e/GEOsubmission/inst/doc/GEOsubmission.Rnw"
microarray2soft(sampleID,'sampleInfo.txt',seriesName,'seriesInfo.txt',
datadir=dataDirectory,writedir=soft_example_dir,
softname=soft_example_name,expressionmatrix='expressionNormalized.txt')



###################################################
### chunk number 8: softContent
###################################################
#line 82 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmperpKJq/R.INSTALL2d80412e/GEOsubmission/inst/doc/GEOsubmission.Rnw"
readLines(soft_example_fullpath)


###################################################
### chunk number 9: deleteSoft
###################################################
#line 86 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmperpKJq/R.INSTALL2d80412e/GEOsubmission/inst/doc/GEOsubmission.Rnw"
## Clean-up
unlink(soft_example_fullpath)


###################################################
### chunk number 10: showExpressionmatrix eval=FALSE
###################################################
## #line 93 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmperpKJq/R.INSTALL2d80412e/GEOsubmission/inst/doc/GEOsubmission.Rnw"
## read.delim(file.path(dataDirectory,'expressionNormalized.txt'))


###################################################
### chunk number 11: exampleWstdOutput eval=FALSE
###################################################
## #line 98 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmperpKJq/R.INSTALL2d80412e/GEOsubmission/inst/doc/GEOsubmission.Rnw"
## microarray2soft(c('1','2'),'sampleInfo.txt',seriesName,'seriesInfo.txt',
## datadir=dataDirectory,softname='',expressionmatrix='expressionNormalized.txt',
## verbose=FALSE)
## 


###################################################
### chunk number 12: sessionInfo
###################################################
#line 111 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmperpKJq/R.INSTALL2d80412e/GEOsubmission/inst/doc/GEOsubmission.Rnw"
sessionInfo()
